export function fedexRate(
  streetLines: any,
  city: any,
  stateOrProvinceCode: any,
  postalCode: any,
  countryCode: any,
  serviceType: any,
  weightValue: any,
  fedexConfig: any) {
  const shippingInfo = fedexConfig.shippingInfo ? JSON.parse(fedexConfig.shippingInfo) : {};
  const shipperAccountNumber = fedexConfig.credentialType === "live" ? fedexConfig.liveShippingAccountNumber : fedexConfig.sandboxShippingAccountNumber;
  const billerAccountNumber = fedexConfig.credentialType === "live" ? fedexConfig.liveBillingAccountNumber : fedexConfig.sandboxBillingAccountNumber;

  return {
    "accountNumber": {
      "value": shipperAccountNumber
    },
    "requestedShipment": {
      "shipper": {
        "address": {
          "streetLines": [
            shippingInfo.shippingAddressLine
          ],
          "city": shippingInfo.shippingCity,
          "stateOrProvinceCode": shippingInfo.shippingStateProvianceCode,
          "postalCode": shippingInfo.shippingPostalCode,
          "countryCode": shippingInfo.countryCode
        }
      },
      "recipient": {
        "address": {
          "streetLines": streetLines,
          "city": city,
          "stateOrProvinceCode": stateOrProvinceCode,
          "postalCode": postalCode,
          "countryCode": countryCode,
          "residential": true
        }
      },
      "serviceType": serviceType,
      "rateRequestType": [
        "ACCOUNT"
      ],
      "preferredCurrency": "USD",
      "pickupType": "USE_SCHEDULED_PICKUP",
      "requestedPackageLineItems": [
        {
          "weight": {
            "units": "LB", //KG
            "value": weightValue
          }
        }
      ],
      "packagingType": "YOUR_PACKAGING"
    }
  };
}

export function fedexShippingCreate(
  streetLines: any,
  city: any,
  stateOrProvinceCode: any,
  postalCode: any,
  countryCode: any,
  serviceType: any,
  weightValue: any,
  fedexConfig: any
) {
  const shippingInfo = fedexConfig.shippingInfo ? JSON.parse(fedexConfig.shippingInfo) : {};
  const shipperAccountNumber = fedexConfig.credentialType === "live" ? fedexConfig.liveShippingAccountNumber : fedexConfig.sandboxShippingAccountNumber;
  const billerAccountNumber = fedexConfig.credentialType === "live" ? fedexConfig.liveBillingAccountNumber : fedexConfig.sandboxBillingAccountNumber;

  return {
    "requestedShipment": {
      "shipper": {
        "address": {
          "streetLines": [
            shippingInfo.shippingAddressLine
          ],
          "city": shippingInfo.shippingCity,
          "stateOrProvinceCode": shippingInfo.shippingStateProvianceCode,
          "postalCode": shippingInfo.shippingPostalCode,
          "countryCode": shippingInfo.countryCode
        },
        "contact": {
          "personName": "Frank Smith",
          "emailAddress": "frank@neutrix.co",
          "phoneExtension": "91",
          "phoneNumber": "1212567890",
          "companyName": "Neutrix"
        }
      },
      "recipients": [
        {
          "address": {
            "streetLines": streetLines,
            "city": city,
            "stateOrProvinceCode": stateOrProvinceCode,
            "postalCode": postalCode,
            "countryCode": countryCode,
            "residential": true
          },
          "contact": {
            "personName": "John Taylor",
            "emailAddress": "sample@company.com",
            "phoneExtension": "000",
            "phoneNumber": "1213345671"
          }
        }
      ],
      "pickupType": "USE_SCHEDULED_PICKUP",
      "serviceType": serviceType,
      "packagingType": "YOUR_PACKAGING",
      "shippingChargesPayment": {
        "paymentType": "SENDER"
      },
      "labelSpecification": {
        "labelStockType": "PAPER_4X8",
        "imageType": "PNG"

      },
      "requestedPackageLineItems": [
        {
          "weight": {
            "units": "KG",
            "value": weightValue
          }
        }
      ]
    },
    "labelResponseOptions": "LABEL",
    "accountNumber": {
      "value": shipperAccountNumber
    }
  };
}

export function fedexShippingValidate(
  streetLines: any,
  city: any,
  stateOrProvinceCode: any,
  postalCode: any,
  countryCode: any,
  serviceType: any,
  weightValue: any,
  fedexConfig: any
) {
  const shippingInfo = fedexConfig.shippingInfo ? JSON.parse(fedexConfig.shippingInfo) : {};
  const shipperAccountNumber = fedexConfig.credentialType === "live" ? fedexConfig.liveShippingAccountNumber : fedexConfig.sandboxShippingAccountNumber;
  const billerAccountNumber = fedexConfig.credentialType === "live" ? fedexConfig.liveBillingAccountNumber : fedexConfig.sandboxBillingAccountNumber;

  return {
    "requestedShipment": {
      "pickupType": "USE_SCHEDULED_PICKUP",
      "serviceType": serviceType,
      "packagingType": "YOUR_PACKAGING",
      "shipper": {
        "address": {
          "streetLines": [
            shippingInfo.shippingAddressLine
          ],
          "city": shippingInfo.shippingCity,
          "stateOrProvinceCode": shippingInfo.shippingStateProvianceCode,
          "postalCode": shippingInfo.shippingPostalCode,
          "countryCode": shippingInfo.countryCode
        },
        "contact": {
          "personName": "Frank Smith",
          "emailAddress": "frank@neutrix.co",
          "phoneExtension": "91",
          "phoneNumber": "1212567890",
          "companyName": "Neutrix"
        }
      },
      "recipients": [
        {
          "address": {
            "streetLines": streetLines,
            "city": city,
            "stateOrProvinceCode": stateOrProvinceCode,
            "postalCode": postalCode,
            "countryCode": countryCode,
            "residential": true
          },
          "contact": {
            "personName": "John Taylor",
            "emailAddress": "sample@company.com",
            "phoneExtension": "000",
            "phoneNumber": "1212345671"
          }
        }
      ],
      "shippingChargesPayment": {
        "paymentType": "SENDER"
      },
      "labelSpecification": {
        "labelStockType": "PAPER_4X8",
        "imageType": "PNG"
      },
      "requestedPackageLineItems": [
        {
          "weight": {
            "units": "KG",
            "value": weightValue
          }
        }
      ]
    },
    "accountNumber": {
      "value": shipperAccountNumber
    }
  };
}